@@ -126,12 +126,13 @@
  *  *patr members set
  */
 
-int decode_unkn(patr, name, rescn, value)
-
-struct attribute *patr;  /* May be Modified on Return */
-char *name;
-char *rescn;
-char *value;
+int
+decode_unkn(
+  struct attribute *patr,  /* May be Modified on Return */
+  char *name,
+  char *rescn,
+  char *value
+)
   {
   svrattrl *entry;
   size_t      valln;
@@ -187,12 +188,14 @@ char *value;
  */
 /*ARGSUSED*/
 
-int encode_unkn(attr, phead, atname, rsname, mode)
-attribute *attr;   /* ptr to attribute to encode */
-tlist_head *phead;   /* list to place entry in */
-char   *atname;  /* attribute name, not used here */
-char   *rsname;  /* resource name, not used here */
-int   mode;   /* encode mode, unused here */
+int
+encode_unkn(
+  attribute *attr,   /* ptr to attribute to encode */
+  tlist_head *phead,   /* list to place entry in */
+  char *atname,  /* attribute name, not used here */
+  char *rsname,  /* resource name, not used here */
+  int mode   /* encode mode, unused here */
+)
   {
   svrattrl *plist;
   svrattrl *pnew;
@@ -312,8 +315,8 @@ comp_unkn(struct attribute *attr, struct attribute *with)
  * For each entry in the list, it is delinked, and freed.
  */
 
-void free_unkn(pattr)
-attribute *pattr;
+void
+free_unkn(attribute *pattr)
   {
   svrattrl *plist;
 
